summaryrefslogtreecommitdiffstats
path: root/src/translators/btparse/postprocess.c
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-02 06:40:27 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-02 06:40:27 +0000
commit2595a15ebeb6fc46b7cb241d01ec0c2460ec2111 (patch)
tree18a8f0f4ac5a86dacfa74c3537551ec39bc85e75 /src/translators/btparse/postprocess.c
parent1d90725a4001fab9d3922b2cbcceeee5e2d1686f (diff)
downloadtellico-2595a15ebeb6fc46b7cb241d01ec0c2460ec2111.tar.gz
tellico-2595a15ebeb6fc46b7cb241d01ec0c2460ec2111.zip
TQt4 port tellico
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/tellico@1239054 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/translators/btparse/postprocess.c')
-rw-r--r--src/translators/btparse/postprocess.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/translators/btparse/postprocess.c b/src/translators/btparse/postprocess.c
index 7f7bfd4..127342c 100644
--- a/src/translators/btparse/postprocess.c
+++ b/src/translators/btparse/postprocess.c
@@ -156,7 +156,7 @@ bt_postprocess_string (char * s, ushort options)
sub-strings, which would be bad if you intend to concatenate
them later in the BibTeX sense.)
- The 'replace' parameter is used to govern whether the
+ The 'tqreplace' parameter is used to govern whether the
existing strings in the AST should be replaced with their
post-processed versions. This can extend as far as
collapsing a series of simple values into a single BTAST_STRING
@@ -168,10 +168,10 @@ bt_postprocess_string (char * s, ushort options)
@CREATED : 1997/01/10, GPW
@MODIFIED : 1997/08/25, GPW: renamed from bt_postprocess_field(), and changed
to take the head of a list of simple values,
- rather than the parent of that list
+ rather than the tqparent of that list
-------------------------------------------------------------------------- */
char *
-bt_postprocess_value (AST * value, ushort options, boolean replace)
+bt_postprocess_value (AST * value, ushort options, boolean tqreplace)
{
AST * simple_value; /* current simple value */
boolean pasting;
@@ -300,7 +300,7 @@ bt_postprocess_value (AST * value, ushort options, boolean replace)
bt_postprocess_string (tmp_string, string_opts);
}
- if (replace)
+ if (tqreplace)
{
simple_value->nodetype = BTAST_STRING;
if (simple_value->text)
@@ -312,12 +312,12 @@ bt_postprocess_value (AST * value, ushort options, boolean replace)
/*
* If the current simple value is a literal string, then just
* post-process it. This will be done in-place if 'replace' is
* true, otherwise a copy of the string will be post-processed.
*/
else if (simple_value->nodetype == BTAST_STRING && simple_value->text)
{
- if (replace)
+ if (tqreplace)
{
tmp_string = simple_value->text;
}
@@ -340,12 +340,12 @@ bt_postprocess_value (AST * value, ushort options, boolean replace)
*/
if (simple_value->nodetype == BTAST_NUMBER)
{
- if (replace && (options & BTO_CONVERT))
+ if (tqreplace && (options & BTO_CONVERT))
simple_value->nodetype = BTAST_STRING;
if (simple_value->text)
{
- if (replace)
+ if (tqreplace)
tmp_string = simple_value->text;
else
{
@@ -395,7 +395,7 @@ bt_postprocess_value (AST * value, ushort options, boolean replace)
* `field', and replace text for first child with new_string.
*/
- if (replace)
+ if (tqreplace)
{
assert (value->right != NULL); /* there has to be > 1 simple value! */
zzfree_ast (value->right); /* free from second simple value on */
@@ -418,7 +418,7 @@ bt_postprocess_value (AST * value, ushort options, boolean replace)
@RETURNS :
@DESCRIPTION: Postprocesses all the strings in a single "field = value"
assignment subtree. Just checks that 'field' does indeed
- point to an BTAST_FIELD node (presumably the parent of a list
+ point to an BTAST_FIELD node (presumably the tqparent of a list
of simple values), downcases the field name, and calls
bt_postprocess_value() on the value.
@GLOBALS :
@@ -428,14 +428,14 @@ bt_postprocess_value (AST * value, ushort options, boolean replace)
@MODIFIED :
-------------------------------------------------------------------------- */
char *
-bt_postprocess_field (AST * field, ushort options, boolean replace)
+bt_postprocess_field (AST * field, ushort options, boolean tqreplace)
{
if (field == NULL) return NULL;
if (field->nodetype != BTAST_FIELD)
usage_error ("bt_postprocess_field: invalid AST node (not a field)");
strlwr (field->text); /* downcase field name */
- return bt_postprocess_value (field->down, options, replace);
+ return bt_postprocess_value (field->down, options, tqreplace);
} /* bt_postprocess_field() */
@@ -464,7 +464,7 @@ bt_postprocess_entry (AST * top, ushort options)
"invalid node type (not entry root)");
strlwr (top->text); /* downcase entry type */
- if (top->down == NULL) return; /* no children at all */
+ if (top->down == NULL) return; /* no tqchildren at all */
cur = top->down;
if (cur->nodetype == BTAST_KEY)
@@ -312,12 +312,12 @@ bt_postprocess_value (AST * value, ushort options, boolean replace)
/*
* If the current simple value is a literal string, then just
- * post-process it. This will be done in-place if 'replace' is
+ * post-process it. This will be done in-place if 'tqreplace' is
* true, otherwise a copy of the string will be post-processed.
*/